from enum import IntEnum


class Order(IntEnum):
    """ Order to choose """

    TO_RIGHT = -1
    TO_LEFT = 0
